@@ -22,7 +22,7 @@ def install(basepath, name):
         Install Honcho/Foreman Module
     """
     proc_file = open(os.path.join(basepath,"Procfile"), "a")
-    proc_file.write("web: python server.py")
+    proc_file.write("web: python server.py\n")
     proc_file.close()
     return
     
@@ -31,8 +31,8 @@ def install_examples(basepath, name):
         Install Honcho/Foreman Module examples
     """
     proc_file = open(os.path.join(basepath,"Procfile"), "a")
-    proc_file.write("##Uncomment to enable:")
-    proc_file.write("# web: python tornado.py # tornado web server")
-    proc_file.write("# clock: python clock.py # clock / cron daemon")
+    proc_file.write("##Uncomment to enable:\n")
+    proc_file.write("# web: python tornado.py # tornado web server\n")
+    proc_file.write("# clock: python clock.py # clock / cron daemon\n")
     proc_file.close()
     return
\ No newline at end of file
